@@ -32,12 +32,8 @@ impl WholeStreamCommand for Histogram {
         "Creates a new table with a histogram based on the column name passed in."
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        histogram(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        histogram(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -62,13 +58,9 @@ impl WholeStreamCommand for Histogram {
     }
 }
 
-pub async fn histogram(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+pub async fn histogram(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name = args.call_info.name_tag.clone();
-    let (input, args) = args.evaluate_once(&registry).await?.parts();
+    let (input, args) = args.evaluate_once().await?.parts();
 
     let values: Vec<Value> = input.collect().await;
 
@@ -98,7 +90,7 @@ pub async fn histogram(
     } else if let Some((key, _)) = columns[0].split_last() {
         key.as_string()
     } else {
-        "frecuency".to_string()
+        "frequency".to_string()
     };
 
     let column = if let Some(ref column) = column_grouper {
@@ -157,7 +149,7 @@ pub async fn histogram(
                     .ok_or_else(|| {
                         ShellError::labeled_error(
                             "Unable to load group labels",
-                            "unabled to load group labels",
+                            "unable to load group labels",
                             &name,
                         )
                     })?
