@@ -25,21 +25,16 @@ impl WholeStreamCommand for SubCommand {
         "Gets the median of a list of numbers"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
         run_with_function(
             RunnableContext {
                 input: args.input,
-                registry: registry.clone(),
+                scope: args.scope.clone(),
                 shell_manager: args.shell_manager,
                 host: args.host,
                 ctrl_c: args.ctrl_c,
                 current_errors: args.current_errors,
                 name: args.call_info.name_tag,
-                raw_input: args.raw_input,
             },
             median,
         )
