@@ -124,12 +124,8 @@ impl WholeStreamCommand for ToHTML {
         "Convert table into simple HTML"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        to_html(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        to_html(args).await
     }
 }
 
@@ -272,11 +268,7 @@ fn get_list_of_theme_names() -> Vec<String> {
     theme_names
 }
 
-async fn to_html(
-    args: CommandArgs,
-    registry: &CommandRegistry,
-) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+async fn to_html(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name_tag = args.call_info.name_tag.clone();
     let (
         ToHTMLArgs {
@@ -288,11 +280,11 @@ async fn to_html(
             list,
         },
         input,
-    ) = args.process(&registry).await?;
+    ) = args.process().await?;
     let input: Vec<Value> = input.collect().await;
     let headers = nu_protocol::merge_descriptors(&input);
     let headers = Some(headers)
-        .filter(|headers| !headers.is_empty() && (headers.len() > 1 || headers[0] != ""));
+        .filter(|headers| !headers.is_empty() && (headers.len() > 1 || !headers[0].is_empty()));
     let mut output_string = String::new();
     let mut regex_hm: HashMap<u32, (&str, String)> = HashMap::new();
 
