@@ -30,12 +30,8 @@ impl WholeStreamCommand for ToMarkdown {
         "Convert table into simple Markdown"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        to_md(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        to_md(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -54,17 +50,16 @@ impl WholeStreamCommand for ToMarkdown {
     }
 }
 
-async fn to_md(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputStream, ShellError> {
-    let registry = registry.clone();
+async fn to_md(args: CommandArgs) -> Result<OutputStream, ShellError> {
     let name_tag = args.call_info.name_tag.clone();
-    let (ToMarkdownArgs { pretty }, input) = args.process(&registry).await?;
+    let (ToMarkdownArgs { pretty }, input) = args.process().await?;
     let input: Vec<Value> = input.collect().await;
     let headers = nu_protocol::merge_descriptors(&input);
 
     let mut escaped_headers: Vec<String> = Vec::new();
     let mut column_widths: Vec<usize> = Vec::new();
 
-    if !headers.is_empty() && (headers.len() > 1 || headers[0] != "") {
+    if !headers.is_empty() && (headers.len() > 1 || !headers[0].is_empty()) {
         for header in &headers {
             let escaped_header_string = htmlescape::encode_minimal(&header);
             column_widths.push(escaped_header_string.len());
