@@ -1,8 +1,5 @@
-use crate::command_registry::CommandRegistry;
 use crate::commands::WholeStreamCommand;
 use crate::prelude::*;
-use indexmap::indexmap;
-use indexmap::map::IndexMap;
 use nu_errors::ShellError;
 use nu_protocol::{Signature, UntaggedValue};
 
@@ -22,12 +19,8 @@ impl WholeStreamCommand for Uniq {
         "Return the unique rows"
     }
 
-    async fn run(
-        &self,
-        args: CommandArgs,
-        registry: &CommandRegistry,
-    ) -> Result<OutputStream, ShellError> {
-        uniq(args, registry).await
+    async fn run(&self, args: CommandArgs) -> Result<OutputStream, ShellError> {
+        uniq(args).await
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -61,8 +54,8 @@ impl WholeStreamCommand for Uniq {
     }
 }
 
-async fn uniq(args: CommandArgs, registry: &CommandRegistry) -> Result<OutputStream, ShellError> {
-    let args = args.evaluate_once(&registry).await?;
+async fn uniq(args: CommandArgs) -> Result<OutputStream, ShellError> {
+    let args = args.evaluate_once().await?;
     let should_show_count = args.has("count");
     let input = args.input;
     let uniq_values = {
