@@ -1,21 +1,17 @@
 // TODO: Temporary redirect
-use crate::command_registry::CommandRegistry;
 use crate::evaluate::evaluate_baseline_expr;
-use indexmap::IndexMap;
-use nu_errors::ShellError;
-use nu_protocol::{hir, EvaluatedArgs, Scope, UntaggedValue, Value};
-use std::sync::Arc;
+use crate::prelude::*;
+use nu_protocol::{hir, EvaluatedArgs, UntaggedValue, Value};
 
 pub(crate) async fn evaluate_args(
     call: &hir::Call,
-    registry: &CommandRegistry,
-    scope: Arc<Scope>,
+    ctx: &EvaluationContext,
 ) -> Result<EvaluatedArgs, ShellError> {
     let mut positional_args: Vec<Value> = vec![];
 
     if let Some(positional) = &call.positional {
         for pos in positional {
-            let result = evaluate_baseline_expr(pos, registry, scope.clone()).await?;
+            let result = evaluate_baseline_expr(pos, ctx).await?;
             positional_args.push(result);
         }
     }
@@ -35,10 +31,7 @@ pub(crate) async fn evaluate_args(
                     named_args.insert(name.clone(), UntaggedValue::boolean(true).into_value(tag));
                 }
                 hir::NamedValue::Value(_, expr) => {
-                    named_args.insert(
-                        name.clone(),
-                        evaluate_baseline_expr(expr, registry, scope.clone()).await?,
-                    );
+                    named_args.insert(name.clone(), evaluate_baseline_expr(expr, ctx).await?);
                 }
                 _ => {}
             };
